#ifndef R_SFHEADERS_H
#define R_SFHEADERS_H

#include <Rcpp.h>

#include "geometries/utils/utils.hpp"

#include "sfheaders/sfg/sfg.hpp"
#include "sfheaders/sfc/sfc.hpp"
#include "sfheaders/sf/sf.hpp"


// // from r-spatial/sf
// #define SF_Unknown             0 /* sfc_GEOMETRY */
// #define SF_Point               1
// #define SF_LineString          2
// #define SF_Polygon             3
// #define SF_MultiPoint          4
// #define SF_MultiLineString     5
// #define SF_MultiPolygon        6
// #define SF_GeometryCollection  7
// #define SF_CircularString      8
// #define SF_CompoundCurve       9
// #define SF_CurvePolygon       10
// #define SF_MultiCurve         11
// #define SF_MultiSurface       12
// #define SF_Curve              13
// #define SF_Surface            14
// #define SF_PolyhedralSurface  15
// #define SF_TIN                16
// #define SF_Triangle           17

// #define SFC_POINT           1;
// #define SFC_MULTIPOINT      2;
// #define SFC_LINESTRING      3;
// #define SFC_MULTILINESTRING 4;
// #define SFC_POLYGON         5;
// #define SFC_MULTIPOLYGON    6;

#endif
